@@ -17,11 +17,26 @@ async def check_interrupt_file(interval, interrupt_file, chat_task):
             break
 
 
-async def run_with_interrupt_check(conversation_history, user_input, cwd: str, abilities, has_any_tool, bot_setting, interrupt_file):
+async def run_with_interrupt_check(
+    conversation_history,
+    user_input,
+    cwd: str,
+    abilities,
+    has_any_tool,
+    bot_setting,
+    interrupt_file,
+):
     clear_chat_data()
     try:
         chat_task = asyncio.create_task(
-            handle_user_inputs(conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting)
+            handle_user_inputs(
+                conversation_history,
+                user_input,
+                cwd,
+                abilities,
+                has_any_tool,
+                bot_setting,
+            )
         )
         check_task = asyncio.create_task(
             check_interrupt_file(0.5, interrupt_file, chat_task)
@@ -70,14 +85,27 @@ def chat(bot_setting_file: str):
         if "interruptFile" in params:
             asyncio.run(
                 run_with_interrupt_check(
-                    conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting, params["interruptFile"]
+                    conversation_history,
+                    user_input,
+                    cwd,
+                    abilities,
+                    has_any_tool,
+                    bot_setting,
+                    params["interruptFile"],
                 )
             )
         else:
             asyncio.run(
-                handle_user_inputs(conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting)
+                handle_user_inputs(
+                    conversation_history,
+                    user_input,
+                    cwd,
+                    abilities,
+                    has_any_tool,
+                    bot_setting,
+                )
             )
-
+        print("has_output")
         output("assistant", CHAT_DATA["info"])
 
 
@@ -94,7 +122,9 @@ def get_chat_response(bot_setting_file: str, user_input: str):
         }
     ]
     asyncio.run(
-        handle_user_inputs(conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting)
+        handle_user_inputs(
+            conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting
+        )
     )
 
     return CHAT_DATA["info"]
