@@ -7,10 +7,13 @@ from .tools import ToolExecutor
 from typing import List
 
 
-def guess_files_in_message(cwd:str, user_message: str) -> List[str]:
+def guess_files_in_message(cwd: str, user_message: str) -> List[str]:
 
-    value = extract({"includedFiles": ['relative path format', 'relative path format', '...']}, 
-                    'Please find the files mentioned in the text. If none, return {"includedFiles": []}:\n' + user_message)
+    value = extract(
+        {"includedFiles": ["relative path format", "relative path format", "..."]},
+        'Please find the files mentioned in the text. If none, return {"includedFiles": []}:\n'
+        + user_message,
+    )
     return [resolve_relative_path(cwd, p) for p in value["includedFiles"]]
 
 
@@ -25,9 +28,15 @@ def user_task_prompt(conversation_history, cwd, user_input: str, programmer_mode
             if os.path.isfile(file_path):
                 file_marker = f"[[{file_path}]]'"
                 file_content = read_local_file(file_path)
-                if not any(file_marker in msg["content"] for msg in conversation_history):
+                if not any(
+                    file_marker in msg["content"] for msg in conversation_history
+                ):
                     content.append(f"{file_marker}\n{file_content}")
-        content_str = "Partial contents of files are as follows:" + "\n".join(content) if content else ""
+        content_str = (
+            "Partial contents of files are as follows:" + "\n".join(content)
+            if content
+            else ""
+        )
         return f"""
 <task>
 {user_input}
@@ -145,9 +154,11 @@ async def stream_openai_response(conversation_history, start_new_stream):
                 yield ("text", text_content.strip())
 
 
-async def handle_user_inputs(conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting):
-    no_exit_if_incomplete = bot_setting["systemAbility"]['no_exit_if_incomplete']
-    programmer_mode = bot_setting["systemAbility"]['programmer_mode']
+async def handle_user_inputs(
+    conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting
+):
+    no_exit_if_incomplete = bot_setting["systemAbility"]["no_exit_if_incomplete"]
+    programmer_mode = bot_setting["systemAbility"]["programmer_mode"]
 
     start_new_stream = {
         "value": False
@@ -160,7 +171,9 @@ async def handle_user_inputs(conversation_history, user_input, cwd, abilities, h
     conversation_history.append(
         {
             "role": "user",
-            "content": user_task_prompt(conversation_history, cwd, user_input, programmer_mode),
+            "content": user_task_prompt(
+                conversation_history, cwd, user_input, programmer_mode
+            ),
         }
     )
     need_break = False
@@ -174,7 +187,11 @@ async def handle_user_inputs(conversation_history, user_input, cwd, abilities, h
             conversation_history, start_new_stream
         ):
             if len(response) == 2:
-                if response[0] == "text" and response[1].strip() != "" or (response[0] == "json" and not has_any_tool):
+                if (
+                    response[0] == "text"
+                    and response[1].strip() != ""
+                    or (response[0] == "json" and not has_any_tool)
+                ):
                     conversation_history.append(
                         {"role": "assistant", "content": response[1]}
                     )
@@ -206,7 +223,9 @@ async def handle_user_inputs(conversation_history, user_input, cwd, abilities, h
                         )
                         continue
 
-                    ok, is_json_dumps, result = ToolExecutor.execute_tool(cwd, tool_request, abilities)
+                    ok, is_json_dumps, result = ToolExecutor.execute_tool(
+                        cwd, tool_request, abilities
+                    )
                     if ok:
                         info("assistant", "✅\n")
                     else:
@@ -218,13 +237,13 @@ async def handle_user_inputs(conversation_history, user_input, cwd, abilities, h
                         + result
                     )
                     if is_json_dumps:
-                        info("assistant", "```json\n" + result + "\n```\n\n")
+                        info("assistant", "\n```json\n" + result + "\n```\n\n")
                     else:
-                        info("assistant", "```text\n" + result + "\n```\n\n")
+                        info("assistant", "\n```text\n" + result + "\n```\n\n")
                     conversation_history.append(
                         {"role": "assistant", "content": assistant_content}
                     )
-                    if tool_name in ["complete_all_tasks", 'ask_follow_up_question']:
+                    if tool_name in ["complete_all_tasks", "ask_follow_up_question"]:
                         need_break = True
                         break
                     else:
@@ -240,6 +259,7 @@ async def handle_user_inputs(conversation_history, user_input, cwd, abilities, h
             break
         if not no_exit_if_incomplete and not start_new_stream["value"]:
             break
+    print("task end")
 
 
 # 示例调用
