@@ -23,9 +23,15 @@ def clear_chat_data():
 def output(role, content):
     assert role == "assistant"
     CHAT_DATA["output"] = content
-    print(_OUTPUT_MESSAGE + json.dumps({"role": role, "content": content}))
+    print(
+        _OUTPUT_MESSAGE
+        + json.dumps({"role": role, "content": content}, ensure_ascii=False)
+    )
 
 
 def info(role, content):
     CHAT_DATA["info"] += content
-    print(_INFOMATION_MESSAGE + json.dumps({"role": role, "content": content}))
+    print(
+        _INFOMATION_MESSAGE
+        + json.dumps({"role": role, "content": content}, ensure_ascii=False)
+    )
