@@ -53,7 +53,7 @@ class ExecuteCommandTool(Tool):
                 shell=True,
                 capture_output=True,
                 text=True,
-                cwd=self.cwd
+                cwd=self.cwd,
             )
             if result.returncode != 0:
                 raise subprocess.CalledProcessError(
@@ -73,7 +73,9 @@ class ReadFileTool(Tool):
     """读取文件工具"""
 
     def validate(self) -> bool:
-        return "path" in self.params and os.path.exists(resolve_relative_path(self.cwd, self.params["path"]))
+        return "path" in self.params and os.path.exists(
+            resolve_relative_path(self.cwd, self.params["path"])
+        )
 
     def execute(self) -> str:
         path = resolve_relative_path(self.cwd, self.params["path"])
@@ -196,13 +198,15 @@ class WebAccessTool(Tool):
         try:
             content = web.get_simplified_webpage(url)[: 32 * 1024]
             result = ai.chat(
-                [{
-                    "role": "user",
-                    "content": f"""Please answer user question based on web page content. The user's question is:
+                [
+                    {
+                        "role": "user",
+                        "content": f"""Please answer user question based on web page content. The user's question is:
 {question}
 Web page content is:
-{content}"""
-                }],
+{content}""",
+                    }
+                ],
             )
             return f"Web page access completed, result is: {result}"
         except Exception as e:
@@ -214,10 +218,10 @@ class AskFollowUpQuestionTool(Tool):
     """询问后续问题工具"""
 
     def validate(self) -> bool:
-        return 'question' in self.params
+        return "question" in self.params
 
     def execute(self) -> str:
-        info("assistant", self.params['question'])
+        info("assistant", self.params["question"])
         return f"Asked user: {self.params['question']}, Waiting for user replied.\n\n"
 
 
@@ -225,16 +229,26 @@ class AttemptTaskCompletionTool(Tool):
     """完成所有任务工具"""
 
     def validate(self) -> bool:
-        return 'result' in self.params
+        return "result" in self.params
 
     def execute(self) -> str:
-        result = self.params['result']
-        info("assistant", 'Completed:' + result + "\n")
-        if 'command' in self.params:
-            result = subprocess.run(self.params['command'], shell=True, capture_output=True, text=True, cwd=self.cwd)
+        result = self.params["result"]
+        if (
+            "command" in self.params
+            and self.params["command"] is not None
+            and type(self.params["command"]) == str
+            and len(self.params["command"]) > 0
+        ):
+            result = subprocess.run(
+                self.params["command"],
+                shell=True,
+                capture_output=True,
+                text=True,
+                cwd=self.cwd,
+            )
             return f"Task completed: {result}, executed command: {self.params['command']}, execution result: {result.stdout + result.stderr}"
         else:
-            return f"Task completed: {result}"
+            return f"Task completed: {result}!"
 
 
 class ToolExecutor:
@@ -249,12 +263,12 @@ class ToolExecutor:
         "search_files": SearchFilesTool,
         "list_files": ListFilesTool,
         "access_webpage": WebAccessTool,
-        'ask_follow_up_question': AskFollowUpQuestionTool,
-        'complete_all_tasks': AttemptTaskCompletionTool,
+        "ask_follow_up_question": AskFollowUpQuestionTool,
+        "complete_all_tasks": AttemptTaskCompletionTool,
     }
 
     @classmethod
-    def execute_tool(cls, cwd:str, tool_request, abilities) -> Tuple[bool, bool, any]:
+    def execute_tool(cls, cwd: str, tool_request, abilities) -> Tuple[bool, bool, any]:
         """执行工具"""
         try:
             tool_name = list(tool_request.keys())[0]
@@ -271,12 +285,16 @@ class ToolExecutor:
                     print("Execute tool error:", traceback.format_exc())
                     return False, False, traceback.format_exc()
                 try:
-                    result = json.dumps(result, indent=4)
+                    result = json.dumps(result, indent=4, ensure_ascii=False)
                 except:
                     return True, False, str(result)
-                return True, True,str(result)
+                return True, True, str(result)
             else:
-                return False, False, f"Unknown tool: {tool_name}, the first key of output json ({tool_name}) will be recognized as a tool, so do not output other json except for executing tools."
+                return (
+                    False,
+                    False,
+                    f"Unknown tool: {tool_name}, the first key of output json ({tool_name}) will be recognized as a tool, so do not output other json except for executing tools.",
+                )
             tool = tool_class(params, cwd)
             if not tool.validate():
                 return False, False, "Tool parameter validation failed."
